
:LastChangedDate: $LastChangedDate$
:LastChangedRevision: $LastChangedRevision$
:LastChangedBy: $LastChangedBy$

Twisted Words (IRC and XMPP)
============================

.. toctree::
   :hidden:

   howto/index
   examples/index


- :doc:`Developer guides <howto/index>`: documentation on using Twisted Words to develop your own applications
- :doc:`Examples <examples/index>`: short code examples using Twisted Words
